.. |logo| image:: https://beeware.org/project/projects/libraries/toga/toga.png
    :width: 72px
    :target: https://beeware.org/toga

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/toga-chart.svg
    :target: https://pypi.python.org/pypi/toga-chart
    :alt: Python Versions

.. |version| image:: https://img.shields.io/pypi/v/toga-chart.svg
    :target: https://pypi.python.org/pypi/toga-chart
    :alt: Project version

.. |maturity| image:: https://img.shields.io/pypi/status/toga-chart.svg
    :target: https://pypi.python.org/pypi/toga-chart
    :alt: Project status

.. |license| image:: https://img.shields.io/pypi/l/toga-chart.svg
    :target: https://github.com/beeware/toga-chart/blob/main/LICENSE
    :alt: BSD License

.. |ci| image:: https://github.com/beeware/toga-chart/workflows/CI/badge.svg?branch=main
   :target: https://github.com/beeware/toga-chart/actions
   :alt: Build Status

.. |social| image:: https://img.shields.io/discord/836455665257021440?label=Discord%20Chat&logo=discord&style=plastic
   :target: https://beeware.org/bee/chat/
   :alt: Discord server

|logo|

Toga Chart
==========

|pyversions| |version| |maturity| |license| |ci| |social|

A `Matplotlib <https://matplotlib.org/>`__ chart widget for `Toga
<https://github.com/beeware/toga>`__.

Quickstart
----------

This widget is still in development. We welcome your contributions and feedback!

To get started using Toga Chart, run the following::

    $ git clone https://github.com/beeware/toga-chart
    $ cd toga-chart
    $ python3 -m venv venv
    $ source venv/bin/activate
    (venv) $ pip install -e .
    (venv) $ cd examples
    (venv) $ python -m chart

Documentation
-------------

Documentation for Toga Chart can be found on `Read The Docs
<https://toga-chart.readthedocs.io>`__.

Community
---------

Toga Chart is a widget for Toga, which is part of the `BeeWare suite
<https://beeware.org>`__. You can talk to the community through:

* `@beeware@fosstodon.org on Mastodon <https://fosstodon.org/@beeware>`__

* `Discord <https://beeware.org/bee/chat/>`__

We foster a welcoming and respectful community as described in our
`BeeWare Community Code of Conduct <https://beeware.org/community/behavior/>`__.

Contributing
------------

If you experience problems with Toga Chart, `log them on GitHub
<https://github.com/beeware/toga-chart/issues>`__. If you want to contribute
code, please `fork the code <https://github.com/beeware/toga-chart>`__ and
`submit a pull request <https://github.com/beeware/toga-chart/pulls>`__.
